@@ -8,7 +8,9 @@ from inspect import isclass
 from ipywidgets import widget_serialization
 import ipyvue
 
-from astropy.nddata import CCDData
+from astropy.nddata import CCDData, NDData
+from astropy.io import fits
+
 from echo import CallbackProperty, DictCallbackProperty, ListCallbackProperty
 from ipygoldenlayout import GoldenLayout
 from ipysplitpanes import SplitPanes
@@ -188,6 +190,7 @@ class Application(VuetifyTemplate, HubListener):
 
     def __init__(self, configuration=None, *args, **kwargs):
         super().__init__(*args, **kwargs)
+        self._jdaviz_helper = None
         self._verbosity = 'warning'
         self._history_verbosity = 'info'
         self.popout_button = PopoutButton(self)
@@ -252,9 +255,6 @@ class Application(VuetifyTemplate, HubListener):
         self.hub.subscribe(self, SnackbarMessage,
                            handler=self._on_snackbar_message)
 
-        # Add callback that updates the layout when the data item array changes
-        self.state.add_callback('stack_items', self.vue_relayout)
-
         # Add a fitted_models dictionary that the helpers (or user) can access
         self.fitted_models = {}
 
@@ -575,7 +575,7 @@ class Application(VuetifyTemplate, HubListener):
         """Like :meth:`get_viewer` but use ID instead of reference name.
         This is useful when reference name is `None`.
         """
-        return self._viewer_store[vid]
+        return self._viewer_store.get(vid)
 
     def get_data_from_viewer(self, viewer_reference, data_label=None,
                              cls='default', include_subsets=True):
@@ -676,11 +676,8 @@ class Application(VuetifyTemplate, HubListener):
 
                         data[label] = layer_data
 
-        # If a data label was provided, return only the data requested
-        if data_label is not None:
-            return data.get(data_label)
-
-        return data
+        # If a data label was provided, return only the corresponding data, otherwise return all:
+        return data.get(data_label, data)
 
     def get_subsets_from_viewer(self, viewer_reference, data_label=None, subset_type=None):
         """
@@ -902,7 +899,10 @@ class Application(VuetifyTemplate, HubListener):
 
         if not data_label and hasattr(data, "label"):
             data_label = data.label
-        data_label = data_label or "New Data"
+        data_label = self.return_unique_name(data_label)
+        if data_label in self.data_collection.labels:
+            warnings.warn(f"Overwriting existing data entry with label '{data_label}'")
+
         self.data_collection[data_label] = data
 
         # Send out a toast message
@@ -911,39 +911,102 @@ class Application(VuetifyTemplate, HubListener):
                 f"Data '{data_label}' successfully added.", sender=self, color="success")
             self.hub.broadcast(snackbar_message)
 
-    @staticmethod
-    def _build_data_label(path, ext=None):
-        """ Build a data label from a filename and data extension
-
-        Builds a data_label out of a filename and data extension.
-        If the input string path already ends with a data
-        extension, the label is returned directly.  Otherwise a valid
-        extension must be specified to append to the file stem.
+    def return_data_label(self, loaded_object, ext=None, alt_name=None, check_unique=True):
+        """
+        Returns a unique data label that can be safely used to load data into data collection.
 
         Parameters
         ----------
-            path : str
-                The data filename to use as a
-            ext : str
-                The data extension to access from the file.
+        loaded_object : str or object
+            The path to a data file or FITS HDUList or image object or Spectrum1D or
+            NDData array or numpy.ndarray.
+        ext : str, optional
+            The extension (or other distinguishing feature) of data used to identify it.
+            For example, "filename[FLUX]" where "FLUX" is the ext value.
+        alt_name : str, optional
+            Alternate names that can be used if none of the options provided are valid.
+        check_unique : bool
+            Included so that this method can be used with data label retrieval in addition
+            to generation.
+
         Returns
         -------
-        A string data label used by Glue
-
+        data_label : str
+            A unique data label that at its root is either given by the user at load time
+            or created by Jdaviz using a description of the loaded filetype.
         """
+        data_label = None
 
-        # if path is not a file or already ends in [ ] extension, assume it is a data-label
-        if not os.path.isfile(path) or re.search(r'(.+)(\[(.*?)\])$', path):
-            return path
-        else:
-            assert ext, 'A data extension must be specified'
-            p = pathlib.Path(path)
-            stem = p.stem.split(os.extsep)[0]
-            label = f'{stem}[{ext}]'
-            return label
+        if loaded_object is None:
+            pass
+        elif isinstance(loaded_object, str):
+            # This is either the full file path or the basename or the user input data label
+            if loaded_object.lower().endswith(('.jpg', '.jpeg', '.png')):
+                file_format = loaded_object.lower().split(".")[-1]
+                loaded_object = os.path.splitext(os.path.basename(loaded_object))[0]
+                data_label = f"{loaded_object}[{file_format}]"
+            elif os.path.isfile(loaded_object) or os.path.isdir(loaded_object):
+                # File that is not an image file
+                data_label = os.path.splitext(os.path.basename(loaded_object))[0]
+            else:
+                # Not a file path so assumed to be a data label
+                data_label = loaded_object
+        elif isinstance(loaded_object, fits.hdu.hdulist.HDUList):
+            if hasattr(loaded_object, 'file_name'):
+                data_label = f"{loaded_object.file_name}[HDU object]"
+            else:
+                data_label = "Unknown HDU object"
+        elif isinstance(loaded_object, Spectrum1D):
+            data_label = "Spectrum1D"
+        elif isinstance(loaded_object, NDData):
+            data_label = "NDData"
+        elif isinstance(loaded_object, np.ndarray):
+            data_label = "Array"
+
+        if data_label is None and alt_name is not None and isinstance(alt_name, str):
+            data_label = alt_name
+        elif data_label is None:
+            data_label = "Unknown"
+
+        if check_unique:
+            data_label = self.return_unique_name(data_label, ext=ext)
+
+        return data_label
+
+    def return_unique_name(self, data_label, ext=None):
+        if data_label is None:
+            data_label = "Unknown"
+
+        # This regex checks for any length of characters that end
+        # with a space followed by parenthesis with a number inside.
+        # If there is a match, the space and parenthesis section will be
+        # removed so that the remainder of the label can be checked
+        # against the data_label.
+        check_if_dup = re.compile(r"(.*)(\s\(\d*\))$")
+        labels = self.data_collection.labels
+        number_of_duplicates = 0
+        for label in labels:
+            # If label is a duplicate of another label
+            if re.fullmatch(check_if_dup, label):
+                label_split = label.split(" ")
+                label_without_dup = " ".join(label_split[:-1])
+                label = label_without_dup
+
+            if ext and f"{data_label}[{ext}]" == label:
+                number_of_duplicates += 1
+            elif ext is None and data_label == label:
+                number_of_duplicates += 1
+
+        if ext:
+            data_label = f"{data_label}[{ext}]"
+
+        if number_of_duplicates > 0:
+            data_label = f"{data_label} ({number_of_duplicates})"
+
+        return data_label
 
     def add_data_to_viewer(self, viewer_reference, data_label,
-                           clear_other_data=False):
+                           visible=True, clear_other_data=False):
         """
         Plots a data set from the data collection in the specific viewer.
 
@@ -954,40 +1017,17 @@ class Application(VuetifyTemplate, HubListener):
             in the yaml configuration file.
         data_label : str
             The Glue data label found in the ``DataCollection``.
+        visible : bool
+            Whether the layer should be initialized as visibile.
         clear_other_data : bool
             Removes all other currently plotted data and only shows the newly
             defined data set.
         """
-        viewer_item = self._viewer_item_by_reference(viewer_reference)
-        if viewer_item is None:  # Maybe they mean the ID
-            viewer_item = self._viewer_item_by_id(viewer_reference)
+        viewer_item = self._get_viewer_item(viewer_reference)
         if viewer_item is None:
             raise ValueError(f"Could not identify viewer with reference {viewer_reference}")
 
-        data_id = self._data_id_from_label(data_label)
-
-        if clear_other_data:
-            self._update_selected_data_items(viewer_item['id'], {})
-
-        selected_data_items = viewer_item['selected_data_items']
-
-        if data_id is not None:
-            selected_data_items[data_id] = 'visible'
-            self._update_selected_data_items(viewer_item['id'], selected_data_items)
-        else:
-            # This block breaks backward compatibility with version<=3.0, where
-            # the second arg in `add_data_to_viewer` was `data_path` instead of
-            # `data_label`. When `data_label` is a file path and that file exists,
-            # raise an error which asks if user means to *load* data.
-            if os.path.exists(data_label):
-                raise ValueError(f'The data label "{data_label}" is not available '
-                                 f'to add to the viewer, but it does specify a file path. '
-                                 f'If you intended to load the data from that file, use the '
-                                 f'`load_data` method or similar.')
-            raise ValueError(
-                f"No data item found with label '{data_label}'. Label must be one "
-                "of:\n\t" + "\n\t".join([
-                    data_item['name'] for data_item in self.state.data_items]))
+        self.set_data_visibility(viewer_item, data_label, visible=visible, replace=clear_other_data)
 
     def _set_plot_axes_labels(self, viewer_id):
         """
@@ -1014,17 +1054,26 @@ class Application(VuetifyTemplate, HubListener):
         data_label : str
             The Glue data label found in the ``DataCollection``.
         """
-        viewer_item = self._viewer_item_by_reference(viewer_reference)
-        data_id = self._data_id_from_label(data_label)
+        viewer_item = self._get_viewer_item(viewer_reference)
+        viewer_id = viewer_item['id']
+        viewer = self.get_viewer_by_id(viewer_id)
 
+        [data] = [x for x in self.data_collection if x.label == data_label]
+
+        viewer.remove_data(data)
+        viewer._layers_with_defaults_applied = [layer_info for layer_info in viewer._layers_with_defaults_applied  # noqa
+                                                if layer_info['data_label'] != data.label]  # noqa
+        remove_data_message = RemoveDataMessage(data, viewer,
+                                                viewer_id=viewer_id,
+                                                sender=self)
+        self.hub.broadcast(remove_data_message)
+
+        # update data menu entry
         selected_items = viewer_item['selected_data_items']
-
+        data_id = self._data_id_from_label(data_label)
         if data_id in selected_items:
             _ = selected_items.pop(data_id)
 
-        self._update_selected_data_items(
-            viewer_item['id'], selected_items)
-
     def _data_id_from_label(self, label):
         """
         Retrieve the data item given the Glue ``DataCollection`` data label.
@@ -1072,7 +1121,55 @@ class Application(VuetifyTemplate, HubListener):
     def get_viewer_reference_names(self):
         """Return a list of available viewer reference names."""
         # Cannot sort because of None
-        return [self._viewer_item_by_id(vid)['reference'] for vid in self._viewer_store]
+        return [self._viewer_item_by_id(vid).get('reference') for vid in self._viewer_store]
+
+    def _get_first_viewer_reference_name(
+            self, require_no_selected_data=False,
+            require_spectrum_viewer=False,
+            require_spectrum_2d_viewer=False,
+            require_table_viewer=False,
+            require_flux_viewer=False,
+            require_image_viewer=False
+    ):
+        """
+        Return the viewer reference name of the first available viewer.
+        Optionally use ``require_no_selected_data`` to require that the
+        viewer has not yet loaded data, or e.g. ``require_spectrum_viewer``
+        to require that the viewer supports spectrum visualization.
+        """
+        from jdaviz.configs.specviz.plugins.viewers import SpecvizProfileView
+        from jdaviz.configs.specviz2d.plugins import SpectralExtraction
+        from jdaviz.configs.cubeviz.plugins.viewers import CubevizProfileView, CubevizImageView
+        from jdaviz.configs.mosviz.plugins.viewers import (
+            MosvizProfileView, MosvizTableViewer, MosvizProfile2DView
+        )
+
+        spectral_viewers = (SpecvizProfileView, CubevizProfileView, MosvizProfileView)
+        table_viewers = (MosvizTableViewer, )
+        image_viewers = (MosvizProfile2DView, CubevizImageView, SpectralExtraction)
+        flux_viewers = (CubevizImageView, )
+
+        for vid in self._viewer_store:
+            viewer_item = self._viewer_item_by_id(vid)
+            is_returnable = (
+                (require_no_selected_data and not len(viewer_item['selected_data_items'])) or
+                (not require_no_selected_data)
+            )
+            if require_spectrum_viewer:
+                if isinstance(self._viewer_store[vid], spectral_viewers) and is_returnable:
+                    return viewer_item['reference']
+            elif require_table_viewer:
+                if isinstance(self._viewer_store[vid], table_viewers) and is_returnable:
+                    return viewer_item['reference']
+            elif require_image_viewer:
+                if isinstance(self._viewer_store[vid], image_viewers) and is_returnable:
+                    return viewer_item['reference']
+            elif require_flux_viewer:
+                if isinstance(self._viewer_store[vid], flux_viewers) and is_returnable:
+                    return viewer_item['reference']
+            else:
+                if is_returnable:
+                    return viewer_item['reference']
 
     def _viewer_by_id(self, vid):
         """
@@ -1108,7 +1205,7 @@ class Application(VuetifyTemplate, HubListener):
         def find_viewer_item(stack_items):
             for stack_item in stack_items:
                 for viewer_item in stack_item.get('viewers'):
-                    if viewer_item['id'] == vid:
+                    if viewer_item.get('id') == vid:
                         return viewer_item
 
                 if len(stack_item.get('children')) > 0:
@@ -1171,31 +1268,28 @@ class Application(VuetifyTemplate, HubListener):
 
         return viewer_item
 
-    def vue_relayout(self, *args, **kwargs):
+    def _get_viewer_item(self, ref_or_id):
         """
-        Forces any rendered ``Bqplot`` instances to resize themselves.
+        Retrieve a viewer item dictionary by reference or id (trying reference first).
+
+        Parameters
+        ----------
+        ref_or_id : str
+            Reference or ID for viewer defined in the yaml configuration file.
+
+        Returns
+        -------
+        viewer_item : dict
+            The dictionary containing the viewer instances and associated
+            attributes.
         """
-        def resize(stack_items):
-            for stack in stack_items:
-                for viewer_item in stack.get('viewers'):
-                    viewer = self._viewer_by_id(viewer_item['id'])
+        if isinstance(ref_or_id, dict):
+            return ref_or_id
 
-                    if viewer is not None:
-                        viewer.figure_widget.layout.height = '99.9%'
-                        viewer.figure_widget.layout.height = '100%'
-
-                if len(stack.get('children')) > 0:
-                    resize(stack.get('children'))
-
-        resize(self.state.stack_items)
-
-        # resize tray items
-        for tray_item in self.state.tray_items:
-            # access the actual plugin object (there is no store for plugins)
-            tray_obj = widget_serialization['from_json'](tray_item['widget'], None)
-            for bqplot_fig in tray_obj.bqplot_figs_resize:
-                bqplot_fig.layout.height = '99.9%'
-                bqplot_fig.layout.height = '100%'
+        viewer_item = self._viewer_item_by_reference(ref_or_id)
+        if viewer_item is None:  # Maybe they mean the ID
+            viewer_item = self._viewer_item_by_id(ref_or_id)
+        return viewer_item
 
     def vue_destroy_viewer_item(self, cid):
         """
@@ -1231,51 +1325,98 @@ class Application(VuetifyTemplate, HubListener):
 
         self.hub.broadcast(ViewerRemovedMessage(cid, sender=self))
 
-    def vue_data_item_selected(self, event):
+    def vue_data_item_unload(self, event):
         """
-        Callback for selection events in the front-end data list. Selections
-        mean that the checkbox associated with the list item has been toggled.
-        When the checkbox is toggled off, remove the data from the viewer;
-        when it is toggled on, add the data to the viewer.
+        Callback for selection events in the front-end data list when clicking to unload an entry
+        from the viewer.
+        """
+        data_label = self._get_data_item_by_id(event['item_id'])['name']
+        self.remove_data_from_viewer(event['id'], data_label)
+
+    def vue_data_item_visibility(self, event):
+        self.set_data_visibility(event['id'],
+                                 self._get_data_item_by_id(event['item_id'])['name'],
+                                 visible=event['visible'], replace=event.get('replace', False))
+
+    def set_data_visibility(self, viewer_reference, data_label, visible=True, replace=False):
+        """
+        Set the visibility of the layers corresponding to ``data_label`` in a given viewer.
 
         Parameters
         ----------
-        event : dict
-            Traitlet event provided the 'old' and 'new' values.
+        viewer_reference : str
+            Reference (or ID) of the viewer
+        data_label : str
+            Label of the data to set the visiblity.  If not already loaded in the viewer, the
+            data will automatically be loaded before setting the visibility
+        visible : bool
+            Whether to set the layer(s) to visible.
+        replace : bool
+            Whether to disable the visilility of all other layers in the viewer
         """
-        viewer_id, item_id, checked = event['id'], event['item_id'], event['checked']
-        viewer_item = self._viewer_item_by_id(viewer_id)
-        replace = event.get('replace', False)
+        viewer_item = self._get_viewer_item(viewer_reference)
+        viewer_id = viewer_item['id']
+        viewer = self.get_viewer_by_id(viewer_id)
 
-        if viewer_item is None:
-            raise ValueError(f'viewer {viewer_id} not found')
+        # if the data_label is in the app, but not loaded in the viewer, automatically load it first
+        viewer_data_labels = [layer.layer.label for layer in viewer.layers]
+        if data_label not in viewer_data_labels:
+            dc_labels = [data.label for data in self.data_collection]
+            if data_label not in dc_labels:
+                if os.path.exists(data_label):
+                    raise ValueError(f'The data label "{data_label}" is not available '
+                                     f'to add to the viewer, but it does specify a file path. '
+                                     f'If you intended to load the data from that file, use the '
+                                     f'`load_data` method or similar.')
+                raise ValueError(
+                    f"No data item found with label '{data_label}'. Label must be one "
+                    "of:\n\t" + "\n\t".join(dc_labels))
 
+            [data] = [x for x in self.data_collection if x.label == data_label]
+            color_cycler = ColorCycler()
+            viewer.add_data(data, percentile=95, color=color_cycler())
+
+            add_data_message = AddDataMessage(data, viewer,
+                                              viewer_id=viewer_id,
+                                              sender=self)
+            self.hub.broadcast(add_data_message)
+
+        # set visibility state of all applicable layers
+        for layer in viewer.layers:
+            if layer.layer.data.label == data_label:
+                if visible and not layer.visible:
+                    layer.visible = True
+                    layer.update()
+                else:
+                    layer.visible = visible
+
+        # if replace, do another loop (we do a second loop to ensure the visible layer is added
+        # first BEFORE other layers are removed)
         if replace:
-            selected_items = {item_id: 'visible'}
-        elif checked:
-            selected_items = {**viewer_item['selected_data_items'], item_id: 'visible'}
-        else:
-            selected_items = {k: v for k, v in viewer_item['selected_data_items'].items() if k != item_id}  # noqa
+            for layer in viewer.layers:
+                if layer.layer.data.label != data_label:
+                    layer.visible = False
 
-        self._update_selected_data_items(viewer_id, selected_items)
-
-    def vue_data_item_visibility(self, event):
-        viewer_id, item_id, visible = event['id'], event['item_id'], event['visible']
-        viewer_item = self._viewer_item_by_id(viewer_id)
-
-        replace = event.get('replace', False)
+        # update data menu - selected_data_items should be READ ONLY, not modified by the user/UI
         selected_items = viewer_item['selected_data_items']
+        data_id = self._data_id_from_label(data_label)
+        selected_items[data_id] = 'visible' if visible else 'hidden'
+        if replace:
+            for id in selected_items:
+                if id != data_id:
+                    selected_items[id] = 'hidden'
 
-        if replace and visible:
-            # trace items remain selected, even if the mode is in replace
-            keep_selected = [k for k, v in viewer_item['selected_data_items'].items()
-                             if v != 'hidden' and
-                             self._get_data_item_by_id(k).get('type') == 'trace']
-            selected_items = {id: 'visible' if id == item_id or id in keep_selected else 'hidden' for id in selected_items.keys()}  # noqa
-        else:
-            selected_items[item_id] = 'visible' if visible else 'hidden'
+        # Sets the plot axes labels to be the units of the most recently
+        # active data.
+        viewer_data_labels = [layer.layer.label for layer in viewer.layers]
+        if len(viewer_data_labels) > 0 and getattr(self._jdaviz_helper, '_in_batch_load', 0) == 0:
+            active_data = self.data_collection[viewer_data_labels[0]]
+            if (hasattr(active_data, "_preferred_translation")
+                    and active_data._preferred_translation is not None):
+                self._set_plot_axes_labels(viewer_id)
 
-        self._update_selected_data_items(viewer_id, selected_items)
+            if self.config == 'imviz':
+                viewer.on_limits_change()  # Trigger compass redraw
 
     def vue_data_item_remove(self, event):
         self.data_collection.remove(self.data_collection[event['item_name']])
@@ -1297,78 +1438,6 @@ class Application(VuetifyTemplate, HubListener):
         return next((x for x in self.state.data_items
                      if x['id'] == data_id), None)
 
-    def _update_selected_data_items(self, viewer_id, selected_items):
-        # Find the active viewer
-        viewer_item = self._viewer_item_by_id(viewer_id)
-        viewer = self._viewer_by_id(viewer_id)
-
-        if isinstance(selected_items, list):
-            selected_items = {si: 'visible' for si in selected_items}
-        # Update the stored selected data items
-        viewer_item['selected_data_items'] = selected_items
-
-        active_data_labels = []
-
-        color_cycler = ColorCycler()
-
-        viewer_data_labels = [layer.layer.label for layer in viewer.layers]
-
-        # Include any selected data in the viewer
-        for data_id, visibility in selected_items.items():
-            label = self._get_data_item_by_id(data_id)['name']
-
-            if label is None:
-                warnings.warn(f"No data item with id '{data_id}' found in "
-                              f"viewer '{viewer_id}'.")
-                continue
-
-            active_data_labels.append(label)
-
-            if label not in viewer_data_labels:
-                [data] = [x for x in self.data_collection if x.label == label]
-                viewer.add_data(data, percentile=95, color=color_cycler())
-
-                add_data_message = AddDataMessage(data, viewer,
-                                                  viewer_id=viewer_id,
-                                                  sender=self)
-                self.hub.broadcast(add_data_message)
-
-            for layer in viewer.layers:
-                if layer.layer.data.label == label:
-                    if visibility == 'visible' and not layer.visible:
-                        layer.visible = True
-                        layer.update()
-
-                    else:
-                        layer.visible = visibility == 'visible'
-
-        # Remove any deselected data objects from viewer
-        viewer_data = [layer_state.layer
-                       for layer_state in viewer.state.layers
-                       if hasattr(layer_state, 'layer') and
-                       isinstance(layer_state.layer, BaseData)]
-
-        for data in viewer_data:
-            if data.label not in active_data_labels:
-                viewer.remove_data(data)
-                viewer._layers_with_defaults_applied= [layer_info for layer_info in viewer._layers_with_defaults_applied  # noqa
-                                                       if layer_info['data_label'] != data.label]
-                remove_data_message = RemoveDataMessage(data, viewer,
-                                                        viewer_id=viewer_id,
-                                                        sender=self)
-                self.hub.broadcast(remove_data_message)
-
-        # Sets the plot axes labels to be the units of the most recently
-        # active data.
-        if len(active_data_labels) > 0:
-            active_data = self.data_collection[active_data_labels[0]]
-            if (hasattr(active_data, "_preferred_translation")
-                    and active_data._preferred_translation is not None):
-                self._set_plot_axes_labels(viewer_id)
-
-            if self.config == 'imviz':
-                viewer.on_limits_change()  # Trigger compass redraw
-
     def _on_data_added(self, msg):
         """
         Callback for when data is added to the internal ``DataCollection``.
@@ -1522,8 +1591,8 @@ class Application(VuetifyTemplate, HubListener):
             'toolbar': "IPY_MODEL_" + viewer.toolbar.model_id if viewer.toolbar else '',  # noqa
             'layer_options': "IPY_MODEL_" + viewer.layer_options.model_id,
             'viewer_options': "IPY_MODEL_" + viewer.viewer_options.model_id,
-            'selected_data_items': {},  # data-label: visibility state (visible, hidden, mixed)
-            'visible_layers': {},  # label: {color, label_suffix} (read-only access)
+            'selected_data_items': {},  # noqa data_id: visibility state (visible, hidden, mixed), READ-ONLY
+            'visible_layers': {},  # label: {color, label_suffix}, READ-ONLY
             'config': self.config,  # give viewer access to app config/layout
             'data_open': False,
             'collapse': True,
@@ -1555,6 +1624,7 @@ class Application(VuetifyTemplate, HubListener):
         """
         viewer = self._application_handler.new_data_viewer(
             msg.cls, data=msg.data, show=False)
+        viewer.figure_widget.layout.height = '100%'
 
         if msg.x_attr is not None:
             x = msg.data.id[msg.x_attr]
@@ -1640,6 +1710,7 @@ class Application(VuetifyTemplate, HubListener):
                     viewer = self._application_handler.new_data_viewer(
                         viewer_registry.members.get(view['plot'])['cls'],
                         data=None, show=False)
+                    viewer.figure_widget.layout.height = '100%'
 
                     viewer_item = self._create_viewer_item(
                         name=view.get('name'),
@@ -1674,7 +1745,29 @@ class Application(VuetifyTemplate, HubListener):
 
         for name in config.get('tray', []):
             tray = tray_registry.members.get(name)
-            tray_item_instance = tray.get('cls')(app=self)
+            tray_registry_options = tray.get('viewer_reference_name_kwargs', {})
+
+            # Optional keyword arguments are required to initialize some
+            # tray items. These kwargs specify the viewer reference names that are
+            # assumed to be present in the configuration.
+            optional_tray_kwargs = dict()
+
+            # If viewer reference names need to be passed to the tray item
+            # constructor, pass the names into the constructor in the format
+            # that the tray items expect.
+            for opt_attr, [opt_kwarg, get_name_kwargs] in tray_registry_options.items():
+                opt_value = getattr(
+                    self, opt_attr, self._get_first_viewer_reference_name(**get_name_kwargs)
+                )
+
+                if opt_value is None:
+                    continue
+
+                optional_tray_kwargs[opt_kwarg] = opt_value
+
+            tray_item_instance = tray.get('cls')(
+                app=self, **optional_tray_kwargs
+            )
             tray_item_label = tray.get('label')
 
             self.state.tray_items.append({
@@ -1686,7 +1779,6 @@ class Application(VuetifyTemplate, HubListener):
     def _reset_state(self):
         """ Resets the application state """
         self.state = ApplicationState()
-        self.state.add_callback('stack_items', self.vue_relayout)
         self._application_handler._tools = {}
 
     def get_configuration(self, path=None, section=None):
