@@ -14,7 +14,7 @@ from jdaviz.core.user_api import PluginUserApi
 __all__ = ['Slice']
 
 
-@tray_registry('cubeviz-slice', label="Slice")
+@tray_registry('cubeviz-slice', label="Slice", viewer_requirements='spectrum')
 class Slice(PluginTemplateMixin):
     """
     See the :ref:`Slice Plugin Documentation <slice>` for more details.
@@ -46,6 +46,12 @@ class Slice(PluginTemplateMixin):
     show_wavelength = Bool(True).tag(sync=True)
 
     def __init__(self, *args, **kwargs):
+        self._default_spectrum_viewer_reference_name = kwargs.get(
+            "spectrum_viewer_reference_name", "spectrum-viewer"
+        )
+        self._default_image_viewer_reference_name = kwargs.get(
+            "image_viewer_reference_name", "image-viewer"
+        )
         super().__init__(*args, **kwargs)
 
         self._watched_viewers = []
