@@ -31,6 +31,17 @@ class CubevizImageView(JdavizViewerMixin, BqplotImageView):
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
+
+        self._default_flux_viewer_reference_name = kwargs.get(
+            "flux_viewer_reference_name", "flux-viewer"
+        )
+        self._default_uncert_viewer_reference_name = kwargs.get(
+            "uncert_viewer_reference_name", "uncert-viewer"
+        )
+        self._default_spectrum_viewer_reference_name = kwargs.get(
+            "spectrum_viewer_reference_name", "spectrum-viewer"
+        )
+
         self._subscribe_to_layers_update()
         self.state.add_callback('reference_data', self._initial_x_axis)
 
@@ -178,6 +189,10 @@ class CubevizProfileView(SpecvizProfileView):
         # default_tool_priority=['jdaviz:selectslice']
         super().__init__(*args, **kwargs)
 
+        self._default_flux_viewer_reference_name = kwargs.get(
+            "flux_viewer_reference_name", "flux-viewer"
+        )
+
     def _get_spatial_subset_layers(self):
         return [ls for ls in self.state.layers
                 if isinstance(getattr(ls.layer, 'subset_state', None), RoiSubsetState)]
