@@ -99,7 +99,7 @@ class MosvizImageView(JdavizViewerMixin, BqplotImageView):
 
 
 @viewer_registry("mosviz-profile-2d-viewer", label="Spectrum 2D (Mosviz)")
-class MosvizProfile2DView(BqplotImageView, JdavizViewerMixin):
+class MosvizProfile2DView(JdavizViewerMixin, BqplotImageView):
     # Due to limitations in CCDData and 2D data that has spectral and spatial
     #  axes, the default conversion class must handle cubes
     default_class = Spectrum1D
@@ -121,7 +121,15 @@ class MosvizProfile2DView(BqplotImageView, JdavizViewerMixin):
         # Setup viewer option defaults
         self.state.aspect = 'auto'
 
+        self._default_spectrum_viewer_reference_name = kwargs.get(
+            "spectrum_viewer_reference_name", "spectrum-viewer"
+        )
+        self._default_spectrum_viewer_reference_name = kwargs.get(
+            "spectrum_2d_viewer_reference_name", "spectrum-2d-viewer"
+        )
+
         if self.jdaviz_app.config == 'specviz2d':
+            # pass
             self.label_mouseover = None
             self.add_event_callback(self.on_mouse_or_key_event,
                                     events=['mousemove', 'mouseenter', 'mouseleave'])
@@ -223,6 +231,19 @@ class MosvizTableViewer(TableViewer, JdavizViewerMixin):
         self._on_row_selected_begin = None
         self._on_row_selected_end = None
 
+        self._default_table_viewer_reference_name = kwargs.get(
+            "table_viewer_reference_name", "table-viewer"
+        )
+        self._default_spectrum_viewer_reference_name = kwargs.get(
+            "spectrum_viewer_reference_name", "spectrum-viewer"
+        )
+        self._default_spectrum_2d_viewer_reference_name = kwargs.get(
+            "spectrum_2d_viewer_reference_name", "spectrum-2d-viewer"
+        )
+        self._default_image_viewer_reference_name = kwargs.get(
+            "image_viewer_reference_name", "image-viewer"
+        )
+
     def redraw(self):
 
         # Overload to hide components - we do this via overloading instead of
@@ -287,17 +308,17 @@ class MosvizTableViewer(TableViewer, JdavizViewerMixin):
             if data_item.meta.get('Plugin') is not None:
                 if data_item.meta.get('mosviz_row') == selected_index:
                     self.session.hub.broadcast(AddDataToViewerMessage(
-                        'spectrum-viewer', data_item.label, sender=self))
+                        self._default_spectrum_viewer_reference_name, data_item.label, sender=self))
                 else:
                     self.session.hub.broadcast(RemoveDataFromViewerMessage(
-                        'spectrum-viewer', data_item.label, sender=self))
+                        self._default_spectrum_viewer_reference_name, data_item.label, sender=self))
 
         for component in mos_data.components:
             comp_data = mos_data.get_component(component).data
             selected_data = comp_data[selected_index]
 
             if component.label == '1D Spectra':
-                prev_data = self._selected_data.get('spectrum-viewer')
+                prev_data = self._selected_data.get(self._default_spectrum_viewer_reference_name)
                 if prev_data != selected_data:
                     if prev_data:
                         # This covers the cases where data is unit converted
@@ -308,42 +329,54 @@ class MosvizTableViewer(TableViewer, JdavizViewerMixin):
                         for modified_prev_data in all_prev_data:
                             if modified_prev_data:
                                 remove_data_from_viewer_message = RemoveDataFromViewerMessage(
-                                    'spectrum-viewer', modified_prev_data, sender=self)
+                                    self._default_spectrum_viewer_reference_name,
+                                    modified_prev_data, sender=self
+                                )
                                 self.session.hub.broadcast(remove_data_from_viewer_message)
 
                     add_data_to_viewer_message = AddDataToViewerMessage(
-                        'spectrum-viewer', selected_data, sender=self)
+                        self._default_spectrum_viewer_reference_name,
+                        selected_data, sender=self
+                    )
                     self.session.hub.broadcast(add_data_to_viewer_message)
 
-                    self._selected_data['spectrum-viewer'] = selected_data
+                    self._selected_data[
+                        self._default_spectrum_viewer_reference_name
+                    ] = selected_data
 
             if component.label == '2D Spectra':
-                prev_data = self._selected_data.get('spectrum-2d-viewer')
+                prev_data = self._selected_data.get(self._default_spectrum_2d_viewer_reference_name)
                 if prev_data != selected_data:
                     if prev_data:
                         remove_data_from_viewer_message = RemoveDataFromViewerMessage(
-                            'spectrum-2d-viewer', prev_data, sender=self)
+                            self._default_spectrum_2d_viewer_reference_name,
+                            prev_data, sender=self
+                        )
                         self.session.hub.broadcast(remove_data_from_viewer_message)
 
                     add_data_to_viewer_message = AddDataToViewerMessage(
-                        'spectrum-2d-viewer', selected_data, sender=self)
+                        self._default_spectrum_2d_viewer_reference_name,
+                        selected_data, sender=self
+                    )
                     self.session.hub.broadcast(add_data_to_viewer_message)
 
-                    self._selected_data['spectrum-2d-viewer'] = selected_data
+                    self._selected_data[
+                        self._default_spectrum_2d_viewer_reference_name
+                    ] = selected_data
 
             if component.label == 'Images':
-                prev_data = self._selected_data.get('image-viewer')
+                prev_data = self._selected_data.get(self._default_table_viewer_reference_name)
                 if prev_data != selected_data:
                     if prev_data:
                         remove_data_from_viewer_message = RemoveDataFromViewerMessage(
-                            'image-viewer', prev_data, sender=self)
+                            self._default_image_viewer_reference_name, prev_data, sender=self)
                         self.session.hub.broadcast(remove_data_from_viewer_message)
 
                     add_data_to_viewer_message = AddDataToViewerMessage(
-                        'image-viewer', selected_data, sender=self)
+                        self._default_image_viewer_reference_name, selected_data, sender=self)
                     self.session.hub.broadcast(add_data_to_viewer_message)
 
-                    self._selected_data['image-viewer'] = selected_data
+                    self._selected_data[self._default_image_viewer_reference_name] = selected_data
 
         message = TableClickMessage(selected_index=selected_index,
                                     shared_image=self._shared_image,
