@@ -22,7 +22,8 @@ from specreduce import extract
 __all__ = ['SpectralExtraction']
 
 
-@tray_registry('spectral-extraction', label="Spectral Extraction")
+@tray_registry('spectral-extraction', label="Spectral Extraction",
+               viewer_requirements=['spectrum', 'spectrum-2d'])
 class SpectralExtraction(PluginTemplateMixin):
     """
     The Spectral Extraction plugin exposes specreduce methods for tracing, background subtraction,
@@ -138,6 +139,14 @@ class SpectralExtraction(PluginTemplateMixin):
     bg_add_to_viewer_items = List().tag(sync=True)
     bg_add_to_viewer_selected = Unicode().tag(sync=True)
 
+    bg_spec_results_label = Unicode().tag(sync=True)
+    bg_spec_results_label_default = Unicode().tag(sync=True)
+    bg_spec_results_label_auto = Bool(True).tag(sync=True)
+    bg_spec_results_label_invalid_msg = Unicode('').tag(sync=True)
+    bg_spec_results_label_overwrite = Bool().tag(sync=True)
+    bg_spec_add_to_viewer_items = List().tag(sync=True)
+    bg_spec_add_to_viewer_selected = Unicode().tag(sync=True)
+
     bg_sub_results_label = Unicode().tag(sync=True)
     bg_sub_results_label_default = Unicode().tag(sync=True)
     bg_sub_results_label_auto = Bool(True).tag(sync=True)
@@ -171,6 +180,13 @@ class SpectralExtraction(PluginTemplateMixin):
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
+        self._default_spectrum_viewer_reference_name = kwargs.get(
+            "spectrum_viewer_reference_name", "spectrum-viewer"
+        )
+        self._default_spectrum_2d_viewer_reference_name = kwargs.get(
+            "spectrum_2d_viewer_reference_name", "spectrum-2d-viewer"
+        )
+
         self._marks = {}
         self._do_marks = kwargs.get('interactive', True)
 
@@ -233,6 +249,16 @@ class SpectralExtraction(PluginTemplateMixin):
         self.bg_add_results.viewer.filters = ['is_spectrum_2d_viewer']
         self.bg_results_label_default = 'background'
 
+        self.bg_spec_add_results = AddResults(self, 'bg_spec_results_label',
+                                              'bg_spec_results_label_default',
+                                              'bg_spec_results_label_auto',
+                                              'bg_spec_results_label_invalid_msg',
+                                              'bg_spec_results_label_overwrite',
+                                              'bg_spec_add_to_viewer_items',
+                                              'bg_spec_add_to_viewer_selected')
+        self.bg_spec_add_results.viewer.filters = ['is_spectrum_viewer']
+        self.bg_spec_results_label_default = 'background-spectrum'
+
         self.bg_sub_add_results = AddResults(self, 'bg_sub_results_label',
                                              'bg_sub_results_label_default',
                                              'bg_sub_results_label_auto',
@@ -310,20 +336,24 @@ class SpectralExtraction(PluginTemplateMixin):
         default_bg_width = int(np.ceil(width / 10))
         default_width = min(default_bg_width, distance_from_edge * 2)
 
+        # sign for one-sided and single trace-pixel depending on whether the brightest pixel is
+        # above or below the middle of the image
+        if default_bg_width * 2 >= distance_from_edge:
+            sign = 1 if (brightest_pixel < width / 2) else -1
+            default_bg_separation = sign * default_bg_width * 2
+        else:
+            default_bg_separation = default_bg_width * 2
+
         if self.trace_pixel == 0:
             self.trace_pixel = brightest_pixel
         if self.trace_window == 0:
             self.trace_window = default_width
         if self.bg_trace_pixel == 0:
-            self.bg_trace_pixel = brightest_pixel
+            self.bg_trace_pixel = brightest_pixel + default_bg_separation
         if self.bg_separation == 0:
             if default_bg_width * 2 >= distance_from_edge:
                 self.bg_type_selected = 'OneSided'
-                # we want positive separation if brightest_pixel near bottom
-                sign = 1 if (brightest_pixel < width / 2) else -1
-                self.bg_separation = sign * default_bg_width * 2
-            else:
-                self.bg_separation = default_bg_width * 2
+            self.bg_separation = default_bg_separation
         if self.bg_width == 0:
             self.bg_width = default_bg_width
         if self.ext_width == 0:
@@ -392,7 +422,7 @@ class SpectralExtraction(PluginTemplateMixin):
                          'bg': ['trace',
                                 'bg1_center', 'bg1_lower', 'bg1_upper',
                                 'bg2_center', 'bg2_lower', 'bg2_upper',
-                                'extract'],
+                                'bg_spec', 'extract'],
                          'ext': ['trace',
                                  'ext_upper', 'ext_lower',
                                  'extract']}
@@ -410,9 +440,9 @@ class SpectralExtraction(PluginTemplateMixin):
 
         if not self._do_marks:
             return {}
+        viewer2d = self.app.get_viewer(self._default_spectrum_2d_viewer_reference_name)
+        viewer1d = self.app.get_viewer(self._default_spectrum_viewer_reference_name)
 
-        viewer2d = self.app.get_viewer('spectrum-2d-viewer')
-        viewer1d = self.app.get_viewer('spectrum-viewer')
         if not viewer2d.state.reference_data:
             # we don't have data yet for scales, defer initializing
             return {}
@@ -433,11 +463,12 @@ class SpectralExtraction(PluginTemplateMixin):
         # NOTE: += won't trigger the figure to notice new marks
         viewer2d.figure.marks = viewer2d.figure.marks + list(self._marks.values())
 
-        mark1d = PluginLine(viewer1d, visible=self.plugin_opened)
-        self._marks['extract'] = mark1d
+        self._marks['extract'] = PluginLine(viewer1d, visible=self.plugin_opened)
+        self._marks['bg_spec'] = PluginLine(viewer1d, visible=self.plugin_opened, stroke_width=1)  # noqa
 
         # NOTE: += won't trigger the figure to notice new marks
-        viewer1d.figure.marks = viewer1d.figure.marks + [mark1d]
+        viewer1d.figure.marks = viewer1d.figure.marks + [self._marks['extract'],
+                                                         self._marks['bg_spec']]
 
         return self._marks
 
@@ -477,7 +508,7 @@ class SpectralExtraction(PluginTemplateMixin):
         except Exception:
             # NOTE: ignore error, but will be raised when clicking ANY of the export buttons
             for mark in ['trace', 'bg1_center', 'bg1_lower', 'bg1_upper',
-                         'bg2_center', 'bg2_lower', 'bg2_upper']:
+                         'bg2_center', 'bg2_lower', 'bg2_upper', 'bg_spec']:
                 self.marks[mark].clear()
         else:
             xs = range(len(trace.trace))
@@ -510,6 +541,13 @@ class SpectralExtraction(PluginTemplateMixin):
                 for mark in ['bg2_center', 'bg2_lower', 'bg2_upper']:
                     self.marks[mark].clear()
 
+        try:
+            spec = self.export_bg_spectrum()
+        except Exception:
+            self.marks['bg_spec'].clear()
+        else:
+            self.marks['bg_spec'].update_xy(spec.spectral_axis, spec.flux)
+
         self.active_step = 'bg'
         self._update_plugin_marks()
 
@@ -744,6 +782,27 @@ class SpectralExtraction(PluginTemplateMixin):
                                 color='error', sender=self)
             )
 
+    def export_bg_spectrum(self, add_data=False, **kwargs):
+        """
+        Create a background 1D spectrum from the input parameters defined in the plugin.
+
+        Parameters
+        ----------
+        add_data : bool
+            Whether to add the resulting spectrum to the application, according to the options
+            defined in the plugin.
+        """
+        bg = self.export_bg(**kwargs)
+        spec = bg.bkg_spectrum()
+
+        if add_data:
+            self.bg_spec_add_results.add_results_from_plugin(spec, replace=False)
+
+        return spec
+
+    def vue_create_bg_spec(self, *args):
+        self.export_bg_spectrum(add_data=True)
+
     def export_bg_sub(self, add_data=False, **kwargs):
         """
         Create a background-subtracted 2D spectrum from the input parameters defined in the plugin.
