@@ -8,6 +8,7 @@ on the motivation behind this concept.
 """
 import re
 import warnings
+from contextlib import contextmanager
 
 import numpy as np
 import astropy.units as u
@@ -19,7 +20,7 @@ from glue.core.subset import Subset, MaskSubsetState
 from ipywidgets.widgets import widget_serialization
 
 from jdaviz.app import Application
-from jdaviz.core.events import SnackbarMessage
+from jdaviz.core.events import SnackbarMessage, ExitBatchLoadMessage
 from jdaviz.core.template_mixin import show_widget
 
 __all__ = ['ConfigHelper', 'ImageConfigHelper']
@@ -55,7 +56,7 @@ class ConfigHelper(HubListener):
         # give a reference from the app back to this config helper.  These can be accessed from a
         # viewer via viewer.jdaviz_app and viewer.jdaviz_helper
         # if the helper has already been set, this is probably a nested viz tool. Don't overwrite
-        if not hasattr(self.app, '_jdaviz_helper'):
+        if self.app._jdaviz_helper is None:
             self.app._jdaviz_helper = self
 
         self.app.hub.subscribe(self, SubsetCreateMessage,
@@ -63,6 +64,9 @@ class ConfigHelper(HubListener):
         self.app.hub.subscribe(self, SubsetDeleteMessage,
                                handler=lambda msg: self._propagate_callback_to_viewers('_on_subset_delete', msg)) # noqa
 
+        self._in_batch_load = 0
+        self._delayed_show_in_viewer_labels = {}  # label: viewer_reference pairs
+
     def _propagate_callback_to_viewers(self, method, msg):
         # viewers don't have access to the app/hub to subscribe to messages, so we'll
         # catch all messages here and pass them on to each of the viewers that
@@ -71,6 +75,29 @@ class ConfigHelper(HubListener):
             if hasattr(viewer, method):
                 getattr(viewer, method)(msg)
 
+    @contextmanager
+    def batch_load(self):
+        """
+        Context manager to delay linking and loading data into viewers
+        """
+        # we'll use a counter instead of a boolean to allow the user to nest multiple
+        # context managers.  Once they're all exited, then the linking/showing will
+        # take place.
+        self._in_batch_load += 1
+        with self.app.data_collection.delay_link_manager_update():
+            # user entrypoint (anything within the with-statement will get called here)
+            yield
+
+        self._in_batch_load -= 1
+        if not self._in_batch_load:
+            self.app.hub.broadcast(ExitBatchLoadMessage(sender=self.app))
+
+            # add any data to viewers that were requested but deferred
+            for data_label, viewer_ref in self._delayed_show_in_viewer_labels.items():
+                self.app.set_data_visibility(viewer_ref, data_label,
+                                             visible=True, replace=False)
+            self._delayed_show_in_viewer_labels = {}
+
     def load_data(self, data, data_label=None, parser_reference=None, **kwargs):
         if data_label:
             kwargs['data_label'] = data_label
